@@ -2,11 +2,12 @@
 Detect jumps in a science image
 """
 
-import roman_datamodels as rdm
+from roman_datamodels import datamodels as rdd
 import numpy as np
 import time
-from ..stpipe import RomanStep
-from .. roman_datamodels import dqflags
+
+from romancal.stpipe import RomanStep
+from romancal.lib import dqflags
 from stcal.jump.jump import detect_jumps
 
 import logging
@@ -38,7 +39,7 @@ class JumpStep(RomanStep):
     def process(self, input):
 
         # Open input as a Roman DataModel (single integration; 3D arrays)
-        with rdm.RampModel(input) as input_model:
+        with rdd.open(input) as input_model:
 
             # Extract the needed info from the Roman Data Model
             meta = input_model.meta
@@ -46,14 +47,15 @@ class JumpStep(RomanStep):
             r_gdq = input_model.groupdq
             r_pdq = input_model.pixeldq
             r_err = input_model.err
+            result = input_model.copy()
 
             frames_per_group = meta.exposure.nframes
 
             # Modify the arrays for input into the 'common' jump (4D)
-            data = np.broadcast_to(r_data, (1,) + r_data.shape)
-            gdq = np.broadcast_to(r_gdq, (1,) + r_gdq.shape)
-            pdq = np.broadcast_to(r_pdq, (1,) + r_pdq.shape)
-            err = np.broadcast_to(r_err, (1,) + r_err.shape)
+            data = np.copy(r_data[np.newaxis, :])
+            gdq = r_gdq[np.newaxis, :]
+            pdq = r_pdq[np.newaxis, :]
+            err = np.copy(r_err[np.newaxis, :])
 
             tstart = time.time()
 
@@ -85,21 +87,24 @@ class JumpStep(RomanStep):
             # Get the gain and readnoise reference files
             gain_filename = self.get_reference_file(input_model, 'gain')
             self.log.info('Using GAIN reference file: %s', gain_filename)
-            gain_model = rdm.GainModel(gain_filename)
+            gain_model = rdd.GainRefModel(gain_filename)
             gain_2d = gain_model.data
 
             readnoise_filename = self.get_reference_file(input_model, 'readnoise')
             self.log.info('Using READNOISE reference file: %s',
                           readnoise_filename)
-            readnoise_model = rdm.ReadnoiseModel(readnoise_filename)
-            readnoise_2d = readnoise_model.data
+            readnoise_model = rdd.ReadnoiseRefModel(readnoise_filename)
+            readnoise_2d = np.copy(readnoise_model.data)
 
+            # DG 0810/21:  leave for now; make dqflags changes in a later,
+            #              separate PR
             dqflags_d = {}  # Dict of DQ flags
             dqflags_d = {
                 "GOOD": dqflags.group["GOOD"],
                 "DO_NOT_USE": dqflags.group["DO_NOT_USE"],
-                "SATURATED":  dqflags.group["SATURATED"],
-                "JUMP_DET":  dqflags.group["JUMP_DET"]
+                "SATURATED": dqflags.group["SATURATED"],
+                "JUMP_DET": dqflags.group["JUMP_DET"],
+                "NO_GAIN_VALUE": dqflags.pixel["NO_GAIN_VALUE"]
             }
 
             gdq, pdq = detect_jumps(frames_per_group, data, gdq, pdq, err,
@@ -110,6 +115,10 @@ class JumpStep(RomanStep):
                                     flag_4_neighbors,
                                     dqflags_d)
 
+            gdq = gdq[0, :, :, :]
+            pdq = pdq[0, :, :]
+            result.groupdq = gdq.copy()
+            result.pixeldq = pdq.copy()
             gain_model.close()
             readnoise_model.close()
             tstop = time.time()
@@ -117,4 +126,8 @@ class JumpStep(RomanStep):
 
         result.meta.cal_step.jump = 'COMPLETE'
 
+        if self.save_results is not None:
+            ff_path = self.save_model(result, suffix=self.suffix, force=True)
+            self.log.info(f'Interpolated flat written to "{ff_path}".')
+
         return result
