@@ -2,6 +2,7 @@
 This module collects all of the stpipe.Pipeline subclasses
 made available by this package.
 """
+from .exposure_pipeline import ExposurePipeline
 
 
-__all__ = []
+__all__ = ['ExposurePipeline']
