@@ -6,11 +6,12 @@ from romancal.step import FlatFieldStep
 import roman_datamodels as rdm
 from .regtestdata import compare_asdf
 
+
 @pytest.mark.bigdata
 def test_flat_field_image_step(rtdata, ignore_asdf_paths):
 
-    rtdata.get_data("WFI/image/l2_0004_rate.asdf")
-    rtdata.input = "l2_0004_rate.asdf"
+    rtdata.get_data("WFI/image/l2_0005_rate.asdf")
+    rtdata.input = "l2_0005_rate.asdf"
 
     # Test CRDS
     step = FlatFieldStep()
@@ -18,22 +19,21 @@ def test_flat_field_image_step(rtdata, ignore_asdf_paths):
     ref_file_path = step.get_reference_file(model, "flat")
     ref_file_name = os.path.split(ref_file_path)[-1]
     assert "roman_wfi_flat" in ref_file_name
-
-
-    # Test FlatFieldStep
-    output = "l2_0004_rate_flatfieldstep.asdf"
+# Test FlatFieldStep
+    output = "l2_0005_rate_flat.asdf"
     rtdata.output = output
     args = ["romancal.step.FlatFieldStep", rtdata.input]
     RomanStep.from_cmdline(args)
     rtdata.get_truth(f"truth/WFI/image/{output}")
     assert (compare_asdf(rtdata.output, rtdata.truth, **ignore_asdf_paths) is None)
 
+
 @pytest.mark.skip(reason="There are no grism flats.")
 @pytest.mark.bigdata
 def test_flat_field_grism_step(rtdata, ignore_asdf_paths):
 
-    rtdata.get_data("WFI/grism/l2_0004_grism_rate.asdf")
-    rtdata.input = "l2_0004_grism_rate.asdf"
+    rtdata.get_data("WFI/grism/l2_0005_grism_rate.asdf")
+    rtdata.input = "l2_0005_grism_rate.asdf"
 
     # Test CRDS
     step = FlatFieldStep()
@@ -43,7 +43,7 @@ def test_flat_field_grism_step(rtdata, ignore_asdf_paths):
     assert "roman_wfi_flat" in ref_file_name
 
     # Test FlatFieldStep
-    output = "l2_0004_grism_rate_flatfieldstep.asdf"
+    output = "l2_0005_grism_rate_flat.asdf"
     rtdata.output = output
     args = ["romancal.step.FlatFieldStep", rtdata.input]
     RomanStep.from_cmdline(args)
@@ -56,8 +56,8 @@ def test_flat_field_crds_match_image_step(rtdata, ignore_asdf_paths):
     # flat files and successfully make level 2 output
 
     # First file
-    rtdata.get_data("WFI/image/l2_0004_rate.asdf")
-    rtdata.input = "l2_0004_rate.asdf"
+    rtdata.get_data("WFI/image/l2_0005_rate.asdf")
+    rtdata.input = "l2_0005_rate.asdf"
 
     # Test CRDS
     step = FlatFieldStep()
@@ -77,7 +77,7 @@ def test_flat_field_crds_match_image_step(rtdata, ignore_asdf_paths):
                   f'{(flat.meta.useafter < model.meta.observation.start_time)}')
 
     # Test FlatFieldStep
-    output = "l2_0004_rate_flatfieldstep.asdf"
+    output = "l2_0005_rate_flat.asdf"
     rtdata.output = output
     args = ["romancal.step.FlatFieldStep", rtdata.input]
     step.log.info('DMS79 MSG: Running flat fielding step. The first ERROR is expected, '
@@ -94,8 +94,8 @@ def test_flat_field_crds_match_image_step(rtdata, ignore_asdf_paths):
     #  to separate flat files in CRDS.
 
     # Second file
-    rtdata.get_data("WFI/image/l2_0004b_rate.asdf")
-    rtdata.input = "l2_0004b_rate.asdf"
+    rtdata.get_data("WFI/image/l2_0005b_rate.asdf")
+    rtdata.input = "l2_0005b_rate.asdf"
 
     # Test CRDS
     step = FlatFieldStep()
@@ -112,7 +112,7 @@ def test_flat_field_crds_match_image_step(rtdata, ignore_asdf_paths):
                   f'{(flat.meta.useafter < model.meta.observation.start_time)}')
 
     # Test FlatFieldStep
-    output = "l2_0004b_rate_flatfieldstep.asdf"
+    output = "l2_0005b_rate_flat.asdf"
     rtdata.output = output
     args = ["romancal.step.FlatFieldStep", rtdata.input]
     step.log.info('DMS79 MSG: Running flat fielding step. The first ERROR is expected, '
